; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;
;-|AI sw |----------------------------------------------------------------------

[command]
name = "AI_1"
command = D, D, D, D, D, D, D, D
time = 1

[command]
name = "AI_2"
command = D, D, D, D, D, D, D, D
time = 1

[command]
name = "AI_3"
command = D, D, D, D, D, D, D, D
time = 1

[command]
name = "AI_4"
command = z, z, z, z, z, z, z, z
time = 1

[command]
name = "AI_5"
command = z, z, z, z, z, z, z, z
time = 1

[command]
name = "AI_6"
command = z, z, z, z, z, z, z, z
time = 1

[command]
name = "AI_7"
command = B, B, B, B, B, B, B, B
time = 1

[command]
name = "AI_8"
command = B, B, B, B, B, B, B, B
time = 1

[command]
name = "AI_9"
command = B, B, B, B, B, B, B, B
time = 1

[command]
name = "AI_10"
command = x, x, x, x, x, x, x, x
time = 1

[command]
name = "AI_11"
command = x, x, x, x, x, x, x, x
time = 1

[command]
name = "AI_12"
command = x, x, x, x, x, x, x, x
time = 1

[command]
name = "AI_13"
command = U, U, U, U, U, U, U, U
time = 1

[command]
name = "AI_14"
command = U, U, U, U, U, U, U, U
time = 1

[command]
name = "AI_15"
command = U, U, U, U, U, U, U, U
time = 1

[command]
name = "AI_16"
command = a, a, a, a, a, a, a, a
time = 1

[command]
name = "AI_17"
command = a, a, a, a, a, a, a, a
time = 1

[command]
name = "AI_18"
command = a, a, a, a, a, a, a, a
time = 1

[command]
name = "AI_19"
command = F, F, F, F, F, F, F, F
time = 1

[command]
name = "AI_20"
command = F, F, F, F, F, F, F, F
time = 1

[command]
name = "AI_21"
command = F, F, F, F, F, F, F, F
time = 1

[command]
name = "AI_22"
command = b, b, b, b, b, b, b, b
time = 1

[command]
name = "AI_23"
command = b, b, b, b, b, b, b, b
time = 1

[command]
name = "AI_24"
command = b, b, b, b, b, b, b, b
time = 1

[command]
name = "AI_25"
command = y, y, y, y, y, y, y, y
time = 1

[command]
name = "AI_26"
command = y, y, y, y, y, y, y, y
time = 1

[command]
name = "AI_27"
command = y, y, y, y, y, y, y, y
time = 1

[command]
name = "AI_28"
command = s, s, s, s, s, s, s, s
time = 1

[command]
name = "AI_29"
command = s, s, s, s, s, s, s, s
time = 1

[command]
name = "AI_30"
command = s, s, s, s, s, s, s, s
time = 1


;
;-| Super Motions |--------------------------------------------------------
; 4632147 VCjONX^rbgR}h
[Command]
name = "4632147x"
command = ~B, F, D, B,  x
time = 30

[Command]
name = "4632147y"
command = ~B, F, D, B,  y
time = 30

[Command]
name = "4632147z"
command = ~B, F, D, B,  z
time = 30

;-| Super Motions |--------------------------------------------------------
; 632146 TCRC[WiTCLbNXjR}h
[Command]
name = "632146x"
command = ~F, D, B, F,  x
time = 30

[Command]
name = "632146y"
command = ~F, D, B, F,  y
time = 30

[Command]
name = "632146z"
command = ~F, D, B, F,  z
time = 30

;-| Super Motions |--------------------------------------------------------
; 236236 tFjbNX \[h R}h
[Command]
name = "236236x"
command = ~D, F, D, F, x
time = 30

[Command]
name = "236236y"
command = ~D, F, D, F, y
time = 30

[Command]
name = "236236z"
command = ~D, F, D, F, z
time = 30

;-| Special Motions |------------------------------------------------------
[Command]
name = "41236x"
command = ~B, D, F, x

[Command]
name = "41236y"
command = ~B, D, F, y

[Command]
name = "41236z"
command = ~B, D, F, z

[Command]
name = "623x"
command = ~F, D, DF, x

[Command]
name = "623y"
command = ~F, D, DF, y

[Command]
name = "623z"
command = ~F, D, DF, z

[Command]
name = "214xy"
command = ~D, DB, B, x+y

[Command]
name = "214xz"
command = ~D, DB, B, x+z

[Command]
name = "214yz"
command = ~D, DB, B, y+z

[Command]
name = "214x"
command = ~D, DB, B, x

[Command]
name = "214y"
command = ~D, DB, B, y

[Command]
name = "214z"
command = ~D, DB, B, z

[Command]
name = "214a"
command = ~D, DF, F, a

[Command]
name = "214b"
command = ~D, DF, F, b

[Command]
name = "214c"
command = ~D, DF, F, c

[Command]
name = "236x"
command = ~D, DF, F, x

[Command]
name = "236y"
command = ~D, DF, F, y

[Command]
name = "236z"
command = ~D, DF, F, z

[Command]
name = "236a"
command = ~D, DF, F, a

[Command]
name = "236b"
command = ~D, DF, F, b

[Command]
name = "236c"
command = ~D, DF, F, c

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+a
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "back_xy"
command = /$B,x+y
time = 2

[Command]
name = "back_yz"
command = /$B,y+z
time = 2

[Command]
name = "back_xz"
command = /$B,x+z
time = 2

[Command]
name = "back_zc"
command = /$B,z+c
time = 2

[Command]
name = "back_xa"
command = /$B,x+a
time = 2

[Command]
name = "fwd_ab"
command = /$F,a+b
time = 2

[Command]
name = "fwd_ac"
command = /$F,a+c
time = 2

[Command]
name = "fwd_bc"
command = /$F,b+c
time = 2

[Command]
name = "back_ab"
command = /$B,a+b
time = 2

[Command]
name = "back_ac"
command = /$B,a+c
time = 2

[Command]
name = "back_bc"
command = /$B,b+c
time = 2

;-| {^ςȂ |---------------------------------------------------------

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_ab"
command = /a+b
time = 1

[Command]
name = "hold_bc"
command = /b+c
time = 1

[Command]
name = "hold_ac"
command = /a+c
time = 1

[Command]
name = "hold_xy"
command = /x+y
time = 1

[Command]
name = "hold_yz"
command = /y+z
time = 1

[Command]
name = "hold_xz"
command = /x+z
time = 1

[Command]
name = "hold_zc"
command = /c+z
time = 1

;-| Double Button |---------------------------------------------------------
[Command]
name = "xyz"
command = x+y+z
time = 1

[Command]
name = "xy"
command = x+y
time = 1

[Command]
name = "yz"
command = y+z
time = 1

[Command]
name = "xz"
command = x+z
time = 1

[Command]
name = "zc"
command = z+c
time = 1

[Command]
name = "xa"
command = x+a
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "ac"
command = a+c
time = 1

[Command]
name = "bc"
command = b+c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;---------------------------------------------------------------------------
;Player Side
[State -1,PlayerSide_2]
type = Varset
trigger1   = Facing      = -1      ; 2P Side
trigger1   = RoundState  < 2       ; Not in Fight
v = 15
value = 2

;Player Side
[State -1,PlayerSide_1]
type = Varset
trigger1   = Facing       = 1       ; 1P Side
trigger1   = RoundState  < 2       ; Not in Fight
v = 15
value = 1

;jnAjp1(OFF)
[State -1,KObyHyper]
type       = Varset
trigger1   = RoundState  < 2       ; Not in Fight
v          = 5
value      = 0

;jnAjp2(ON)
[State -1,KObyHyper]
type       = Varset
trigger1   = enemynear,hitdefattr = SCA,HA,HP,HT  ; by Hyper Attack
trigger2   = enemynear,movetype = A
trigger2   = enemynear,stateno >= 3000            ; by Hyper Proj
trigger3   = enemynear,PrevStateNo >= 3000        ; //
v          = 6
value      = 100

;jnAjp1(ON)
[State -1,KObyHyper]
type       = Varset
trigger1   = !alive                               ; Dead
trigger1   = Var(6) = 100                         ; by Hyper Attack
trigger1   = enemy,Win                            ; 
v          = 5
value      = 100000

;jnAjp2(Off)
[State -1,KObyHyper]
type       = Varset
trigger1   = alive                                ; Not Dead
trigger1   = movetype != H
v          = 6
value      = 0

;TCRC[Wp
[State -3, AI_PsycoIlusion]
type     = VarAdd
trigger1 = StateNo != [3800,3899]
trigger1 = Var(28) > 0
v        = 28
value    = -1

;Var(14) ON TC  - on -
[State -1, StarMark_2]  
type = explod
trigger1 = var(14)  = 1
trigger1 = var(15)  = 2
trigger1 = NumExplod(14000)  = 0
;persistent = 0
id = 14000
anim = 14000
pos = -5,52
postype = right
sprpriority = 7
removetime = -1
facing=-1
supermove = 1
bindtime = -1
ontop = 1
;ownpal = 1

;Var(14) ON TC  - on -
[State -1, StarMark_1]  
type = explod
trigger1 = var(14)  = 1
trigger1 = var(15)  = 1
trigger1 = NumExplod(14000)  = 0
;persistent = 0
id = 14000
anim = 14000
pos =   5,52 ;0,22
postype = left
sprpriority = 7
removetime = -1
supermove = 1
bindtime = -1
ontop = 1
;ownpal = 1

;Var(14) ON TC  - off -
[State -1, StarMark_off]  
type = RemoveExplod
trigger1 = var(14)  = 0
trigger1 = NumExplod(14000)  = 1
id = 14000

;Var(28) ON TC  - on -
[State -1, StarMark_2]  
type = explod
trigger1 = var(28)  > 0
trigger1 = var(15)  = 2
trigger1 = NumExplod(15000)  = 0
trigger1 = StateNo != [3800,3899]
;persistent = 0
id = 15000
anim = 15000
pos = -15,52
postype = right
sprpriority = 7
removetime = -1
facing=-1
supermove = 1
bindtime = -1
ontop = 1
;ownpal = 1

;Var(28) ON TC  - on -
[State -1, StarMark_1]  
type = explod
trigger1 = var(28)  > 0
trigger1 = var(15)  = 1
trigger1 = NumExplod(15000)  = 0
trigger1 = StateNo != [3800,3899]
;persistent = 0
id = 15000
anim = 15000
pos =   15,52 ;0,22
postype = left
sprpriority = 7
removetime = -1
supermove = 1
bindtime = -1
ontop = 1
;ownpal = 1

;Var(28) ON TC  - off -
[State -1, StarMark_off]  
type = RemoveExplod
trigger1 = var(28)  = 0
trigger1 = NumExplod(15000)  = 1
id = 15000

;===========================================================================
; AI Փxݒ
;-----------------
; Var(29) ɃZbglɂāAAI ɂRg[px𐧌䂵܂B
; AI Ɗꍇ̓Zbgl
; AI シƊꍇ̓Zbgl傫ύXĂB
; 
; [Zbgl̖ڈ]
; 999  FŋBق100̊mAI䂪܂
; 500  FxB 50̊mAI䂪܂
; 128  : WlB 13̊mAI䂪܂
; 0    FOFFB AI䂪ƂȂ܂
;-----------------
[State -1,AI_Dif]
type=VarSet
trigger1   = RoundState  != 2       ; Not in Fight
v          = 29
value      = 128                    ;  ̒lύXAIxύX܂
;===========================================================================
[State -1,AI_Dif]
type=VarSet
trigger1   = RoundState  != 2       ; Not in Fight
trigger1   =  (P2name  =  "Asamiya Athena")       ;  Athena2k2
v          = 29
value      = 999                    ;  AI ނ炢̂ŁAʎdlB^-^;

;===========================================================================
;{[ p
;===========================================================================
;init Var(1)
[State -1,Var_1]
type                = Varset
trigger1            = RoundState  < 2       ; Not in Fight
v                   = 1 
value               = 128                   

;===========================================================================
; AI Control
;===========================================================================

; ΓːiZAI TCR\[hij
[State -1,1]
type = ChangeState
value = 1110
triggerall = Random       < Var(29)      ; Փx
triggerall = ctrl && (var(30)=30)        ; \AI
triggerall = movetype    != H            ; _[WłȂ
triggerall = statetype   != A            ; 󒆂łȂ
trigger1   = var(27) - p2bodydist X >= 6 ; 6hbgȏڋ
trigger1   = p2movetype   = A            ; 肪U
trigger1   = p2bodydist X = ( 0,65)      ; ̋߂

; ̓ːip
[State -1,1]
type       = Varset
trigger1   = var(30) = 30                ; AI̎
var(27)    = ceil(p2bodydist X)

; Psyco Illusion
[State -1,1]
type = ChangeState
value = 3801                        ; Psyco Illusion(Psyco Shoot Finish)
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = Life < 200 
triggerall = PrevStateNo != [3800,3899]
triggerall = var(28)      = 0
trigger1   = p2MoveType  != A
trigger1   = p2bodydist X < 180
trigger1   = p2stateType != A
trigger1   = p2stateType != L
trigger1   = p2Life       > 500
trigger1   = power        > 299

;Phoenix Sword
[State -1,1]
type = ChangeState
value = 4500                        ; Phoenix Sword
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = ((power >= 3000) && (Life < 200)) || (Life < 6) 
trigger1   = PrevStateNo  = 3840    ; @TCRC[WȂ
trigger2   = p2MoveType  != A       ; A肪UłȂ
trigger3   = p2bodydist X < 70      ; BƋ߂
trigger4   = p2bodydist X < 70      ; BƋ߂
trigger4   = p2stateType != L       ;   肪_E


;Phoenix Mutation
[State -1,1]
type       = Varset
triggerall = Random       < Var(29) ; Փx
triggerall = var(30)      = 30      ; AI = on
triggerall = stateno      = 4500    ; tFjbNX\[h
trigger1   = p2bodydist X > 70      ; Ƃ̋
trigger1   = p2StateType != A       ; 肪󒆂ɂ炸
trigger1   = p2StateType != L       ; 肪_EłȂ
trigger1   = p2StateNo   != [120,150];肪h䒆łȂ
v          = 35
value      = 4530                   ; Phoenix Mutation

;Psyco Beam
[State -1,1]
type       = Varset
triggerall = Random       < Var(29) ; Փx
triggerall = var(30)      = 30      ; AI = on
triggerall = stateno      = 4500    ; tFjbNX\[h
trigger1   = p2StateType  = A       ; 肪
trigger2   = p2bodydist X > 70      ; Ƃ̋
v          = 35
value      = 4520                   ; Psyco Beam


; Psyco Illusion
[State -1,1]
type = ChangeState
value = 3800                        ; Psyco Illusion(Psyco Sword Finish)
triggerall = Random < Ceil(Var(29)/3) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = Life < 200 
triggerall = PrevStateNo != [3800,3899]
triggerall = var(28)      = 0
trigger1   = p2MoveType  != A
trigger1   = p2bodydist X < 180
trigger1   = p2stateType != A
trigger1   = p2stateType != L
trigger1   = p2Life       < 450


; Psyco Illusion
[State -1,1]
type = ChangeState
value = 3802                        ; Psyco Illusion(Psyco Shoot Finish)
triggerall = Random < Ceil(Var(29)/3) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = Life < 200 
triggerall = PrevStateNo != [3800,3899]
triggerall = var(28)      = 0
trigger1   = p2MoveType  != A
trigger1   = p2bodydist X < 180
trigger1   = p2stateType != A
trigger1   = p2stateType != L
trigger1   = p2Life       < 550


; vs Proj
[State -1,1]
type = ChangeState
value = 1820                        ; Psyco Refrecter
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
trigger1   = P2name       = "Athena94sp"
trigger1   = P2StateNo    = [1300,1320]
trigger2   =  (P2name  =  "Asamiya Athena")       ;  Athena2k2
trigger2   =  (P2StateNo  = 1200)


; vs Proj
[State -1,1]
type = ChangeState
value = 1320                        ; Psyco Refrecter
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
trigger1   = P2name       = "Athena95ex"
trigger1   = P2StateNo    = [1000,1020]
trigger2   = P2name       = "Athena99"
trigger2   = P2StateNo    = [1000,1010]
trigger3   = P2name       = "Athena95ex"
trigger3   = P2StateNo    = [3100,3120]
trigger4   = P2name       = "geese"
trigger4   = P2StateNo    = [1000,1103]
trigger5   = P2name       = "ffspRyo"
trigger5   = P2StateNo    = [1000,1020]
trigger6   = P2name       = "ffspRyo"
trigger6   = P2StateNo    = [1400,1420]
trigger7   = P2name       = "Athena94sp"
trigger7   = P2StateNo    = [1000,1020]
trigger8   = P2name       = "Athena94sp"
trigger8   = (P2StateNo   = [1600,1620]) || (P2StateNo  = [3200,3250])
trigger9   = (P2name      =  "Athena Asamiya"); && (Authorname = "EI")  ;  AthenaEX
trigger9   = (P2StateNo   = [1400,1450])
trigger10  = (P2name      =  "Athena Asamiya"); && (Authorname = "EI")  ;  AthenaEX
trigger10  = (P2StateNo  = [1000,1010])
trigger11  = (P2name      =  "Athena Asamiya"); && (Authorname != "EI") ;  Athena00
trigger11  = (P2StateNo   = [1000,1050]) || (P2StateNo  = [1100,1150])
trigger12  = (P2name      =  "mysp")
trigger12  = P2StateNo    = [1120,1130]
trigger13  = (P2name      =  "Athena96") || (P2name  =  "Athena97") || (P2name  =  "Athena98")
trigger13  = (P2StateNo   = [1000,1005]) || (P2StateNo  = [1500,1505])
trigger14  = (P2name      =  "Athena99")
trigger14  = (P2StateNo   = [1000,1010]) || (P2StateNo  = [1400,1410])
trigger15  = P2name       = "Athena94sp"
trigger15  = P2StateNo    = 1302        
trigger16  = (P2name      =  "guile")
trigger16  = P2StateNo    = [1000,1020]
trigger17  =  (P2name  =  "Asamiya Athena")       ;  Athena2k2
trigger17  =  (P2StateNo  = 1100) || (P2StateNo  = 1200)
trigger18  =  (P2name  =  "sf2Ken")
trigger18  =  (P2StateNo  = [1000,1020])


;vs Ground StandingNormalAttack
[State -1,1]
type = ChangeState
value = 310                         ; O咸I
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = p2bodydist X < 70      ; Near from  P2
triggerall = p2statetype  = S       ; P2 Standing
triggerall = PrevStateNo != [310,313]; ZJԂȂ
trigger1   = p2MoveType   = A
trigger1   = P2StateNo    < 1000

;vs Ground NormalAttack
[State -1,1]
type = ChangeState
value = 312                         ; O咸I
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = p2bodydist X < 70      ; Near from  P2
triggerall = p2statetype  = C       ; P2 C
triggerall = PrevStateNo != [310,313]; ZJԂȂ
trigger1   = p2MoveType   = A
trigger1   = P2StateNo    < 1000

;Back Step (for Rapid Psyco Ball Mode)
[State -1,1]
type = ChangeState
value = 105                         ; Back Step
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = var(10)      < 2       ; A˃[h Off
triggerall = NumProjID(1000) = 1    ; ʏɃTCR{[P
trigger1   = p2bodydist X > 180     ; Ƃ̋

;Rapid Psyco Ball Mode
[State -1,1]
type = ChangeState
value = 1020                        ; Psyco Ball(L)
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = var(10)      > 1       ; A˃[h On
triggerall = p2bodydist X > 210     ; Ƃ̋
trigger1   = NumProjID(1000) < var(10)

;Rapid Psyco Ball Mode
[State -1,1]
type = ChangeState
value = 1010                        ; Psyco Ball(M)
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = var(10)      > 1       ; A˃[h On
triggerall = p2bodydist X > 180     ; Ƃ̋
trigger1   = NumProjID(1000) < var(10)

;Rapid Psyco Ball Mode
[State -1,1]
type = ChangeState
value = 1000                        ; Psyco Ball(S)
triggerall = Random       < Var(29) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = var(10)      > 1       ; A˃[h On
triggerall = p2bodydist X > 150     ; Ƃ̋
trigger1   = NumProjID(1000) < var(10)

;Psyco Ball
[State -1,1]
type = ChangeState
value = 1000                        ; Psyco Ball(S)
triggerall = Random < Ceil(Var(29)/6) ; Փx
triggerall = statetype    = S       ; Standing
triggerall = ctrl                   ; Enable Control
triggerall = var(30)      = 30      ; AI = on
triggerall = NumProjID(1000) < var(10)
triggerall = p2bodydist X > 180     ; Ƃ̋
triggerall = PrevStateNo != [1000,1020]; ZJԂȂ
trigger1   = p2statetype  =  A
trigger1   = p2stateno    <  1000

;===========================================================================
; AI SW
;===========================================================================
; AI swich -> ON
[State -1,2]
type       = Varset
triggerall = var(30) != 30
trigger1   = command = "AI_1"
trigger2   = command = "AI_2"
trigger3   = command = "AI_3"
trigger4   = command = "AI_4"
trigger5   = command = "AI_5"
trigger6   = command = "AI_6"
trigger7   = command = "AI_7"
trigger8   = command = "AI_8"
trigger9   = command = "AI_9"
trigger10  = command = "AI_10"
trigger11  = command = "AI_11"
trigger12  = command = "AI_12"
trigger13  = command = "AI_13"
trigger14  = command = "AI_14"
trigger15  = command = "AI_15"
trigger16  = command = "AI_16"
trigger17  = command = "AI_17"
trigger18  = command = "AI_18"
trigger19  = command = "AI_19"
trigger20  = command = "AI_20"
trigger21  = command = "AI_21"
trigger22  = command = "AI_22"
trigger23  = command = "AI_23"
trigger24  = command = "AI_24"
trigger25  = command = "AI_25"
trigger26  = command = "AI_26"
trigger27  = command = "AI_27"
trigger28  = command = "AI_28"
trigger29  = command = "AI_29"
trigger30  = command = "AI_30"
v          = 30
value      = 30

;AI I (jnA`hXCb`nee)
[State -1,2]
type=VarSet
trigger1   = P2life <= 0
v          = 30
value      = 0


;;===========================================================================

;;===========================================================================
;---------------------------------------------------------------------------
; tFjbNX \[h
[State -1]
type = ChangeState
value = 4500
triggerall = (command = "236236x") || (command = "236236y") || (command = "236236z")
triggerall = command != "holddown"
triggerall = ((power >= 3000) && (Life < 200)) || (Life < 6) 
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
; TCRC[Wij
[State -1]
type = ChangeState
value = 3800
triggerall = command = "632146x"
triggerall = command != "holddown"
triggerall = (power >= 3000) || (Life < 200) 
triggerall = statetype = S
triggerall = var(28)      = 0
trigger1 = ctrl = 1
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
; TCRC[Wij
[State -1]
type = ChangeState
value = 3801
triggerall = command = "632146y"
triggerall = command != "holddown"
triggerall = (power >= 3000) || (Life < 200) 
triggerall = statetype = S
triggerall = var(28)      = 0
trigger1 = ctrl = 1
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
; TCRC[Wij
[State -1]
type = ChangeState
value = 3802
triggerall = command = "632146z"
triggerall = command != "holddown"
triggerall = (power >= 3000) || (Life < 200) 
triggerall = statetype = S
triggerall = var(28)      = 0
trigger1 = ctrl = 1
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
; VCjONX^rbgij
[State -1]
type = ChangeState
value = 3000
triggerall = command = "4632147x"
triggerall = command != "holddown"
triggerall = (power >= 1000) || (Life < 300) 
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact
trigger15 = (stateno = 810) && time > 14

; VCjONX^rbgij
[State -1]
type = ChangeState
value = 3000
triggerall = command = "214x"
triggerall = command != "holddown"
triggerall = (power >= 1000) || (Life < 300) 
triggerall = statetype = S
trigger1 = (stateno = 810) && time > 14

;---------------------------------------------------------------------------
; VCjONX^rbgij
[State -1]
type = ChangeState
value = 3000
triggerall = command = "4632147y"
triggerall = command != "holddown"
triggerall = (power >= 1000) || (Life < 300) 
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact
trigger15 = (stateno = 810) && time > 14

; VCjONX^rbgij
[State -1]
type = ChangeState
value = 3000
triggerall = command = "214y"
triggerall = command != "holddown"
triggerall = (power >= 1000) || (Life < 300) 
triggerall = statetype = S
trigger1 = (stateno = 810) && time > 14

;---------------------------------------------------------------------------
; VCjONX^rbgij
[State -1]
type = ChangeState
value = 3000
triggerall = command = "4632147z"
triggerall = command != "holddown"
triggerall = (power >= 1000) || (Life < 300) 
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact
trigger15 = (stateno = 810) && time > 14

; VCjONX^rbgij
[State -1]
type = ChangeState
value = 3000
triggerall = command = "214z"
triggerall = command != "holddown"
triggerall = (power >= 1000) || (Life < 300) 
triggerall = statetype = S
trigger1 = (stateno = 810) && time > 14


;---------------------------------------------------------------------------
; VCjONX^rbgi󒆁j
[State -1]
type = ChangeState
value = 3100
triggerall = (command = "4632147x") || (command = "4632147y") || (command = "4632147z")
triggerall = command != "holddown"
triggerall = (power >= 1000) || (Life < 300) 
;triggerall = (statetype != S)
trigger1 = (ctrl = 1) & (statetype = A)
trigger2 = (stateno = 600) || (stateno = 630) || (stateno = 610) || (stateno = 640) || (stateno = 620) || (stateno = 450) || (stateno = 360) || (stateno = 700) 
trigger2 = movecontact
trigger3 = (stateno = 1101) || (stateno = 1111) || (stateno = 1121)   ; PsycoSword(Rising)
;trigger3 = movecontact
trigger4 = (stateno = 1201)   ; FenixAllow(Rolling)
trigger4 = movecontact


;---------------------------------------------------------------------------
;Psyco Sword
;TCR\[h
[State -1, Psyco Sword s]
type = ChangeState
value = 1100
triggerall = command = "623x"
trigger1 = statetype != L
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact
trigger5 = (stateno = 600) || (stateno = 630) || (stateno = 610) || (stateno = 640) || (stateno = 620) || (stateno = 450) || (stateno = 360) || (stateno = 700) 
trigger5 = movecontact

;---------------------------------------------------------------------------
;Psyco Sword
;TCR\[h
[State -1, Psyco Sword m]
type = ChangeState
value = 1110
triggerall = command = "623y"
trigger1 = statetype != L
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact
trigger15 = (stateno = 600) || (stateno = 630) || (stateno = 610) || (stateno = 640) || (stateno = 620) || (stateno = 450) || (stateno = 360) || (stateno = 700) 
trigger15 = movecontact

;---------------------------------------------------------------------------
;Psyco Sword
;TCR\[h
[State -1, Psyco Sword l]
type = ChangeState
value = 1120
triggerall = command = "623z"
trigger1 = statetype != L
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact
trigger15 = (stateno = 600) || (stateno = 630) || (stateno = 610) || (stateno = 640) || (stateno = 620) || (stateno = 450) || (stateno = 360) || (stateno = 700) 
trigger15 = movecontact

;---------------------------------------------------------------------------
;Psyco Refrector
;TCR tN^[
[State -1, Psyco Refrector s]
type = ChangeState
value = 1300
triggerall = command = "41236x"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Refrector
;TCR tN^[
[State -1, Psyco Refrector m]
type = ChangeState
value = 1310
triggerall = command = "41236y"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Refrector
;TCR tN^[
[State -1, Psyco Refrector l]
type = ChangeState
value = 1320
triggerall = command = "41236z"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Ball
;҃TCR{[
[State -1, N Psyco Ball s]
type = ChangeState
value = 1800
triggerall = command = "214xy"
triggerall = NumProjID(1000) < var(10)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Ball
;҃TCR{[
[State -1, N Psyco Ball m]
type = ChangeState
value = 1810
triggerall = command = "214xz"
triggerall = NumProjID(1000) < var(10)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Ball
;҃TCR{[
[State -1, N Psyco Ball l]
type = ChangeState
value = 1820
triggerall = command = "214yz"
triggerall = NumProjID(1000) < var(10)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Ball
;TCR{[
[State -1, Psyco Ball s]
type = ChangeState
value = 1000
triggerall = command = "214x"
triggerall = NumProjID(1000) < var(10)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Ball
;TCR{[
[State -1, Psyco Ball m]
type = ChangeState
value = 1010
triggerall = command = "214y"
triggerall = NumProjID(1000) < var(10)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Ball
;TCR{[
[State -1, Psyco Ball l]
type = ChangeState
value = 1020
triggerall = command = "214z"
triggerall = NumProjID(1000) < var(10)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Fhenix Allow
;tFjbNX A[
[State -1, Fhenix Allow s]
type = ChangeState
value = 1200
triggerall = command = "214x"
trigger1 = statetype = a
trigger1 = ctrl
trigger2 = (stateno = 600) || (stateno = 630) || (stateno = 610) || (stateno = 640) || (stateno = 620) || (stateno = 450) || (stateno = 360) || (stateno = 700) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Fhenix Allow
;tFjbNX A[
[State -1, Fhenix Allow m]
type = ChangeState
value = 1210
triggerall = command = "214y"
trigger1 = statetype = a
trigger1 = ctrl
trigger2 = (stateno = 600) || (stateno = 630) || (stateno = 610) || (stateno = 640) || (stateno = 620) || (stateno = 450) || (stateno = 360) || (stateno = 700) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Fhenix Allow
;tFjbNX A[
[State -1, Fhenix Allow l]
type = ChangeState
value = 1220
triggerall = command = "214z"
trigger1 = statetype = a
trigger1 = ctrl
trigger2 = (stateno = 600) || (stateno = 630) || (stateno = 610) || (stateno = 640) || (stateno = 620) || (stateno = 450) || (stateno = 360) || (stateno = 700) 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Psyco Shoot
;TCRV[g
[State -1, Psyco Shoot s]
type = ChangeState
value = 1600
triggerall = command = "236x"
;triggerall = NumProjID(1000) < var(10)
triggerall = NumProjID(1600) < 1
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Shoot
;TCRV[g
[State -1, Psyco Shoot m]
type = ChangeState
value = 1610
triggerall = command = "236y"
;triggerall = NumProjID(1000) < var(10)
triggerall = NumProjID(1600) < 1
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Psyco Shoot
;TCRV[g
[State -1, Psyco Shoot l]
type = ChangeState
value = 1620
triggerall = command = "236z"
;triggerall = NumProjID(1000) < var(10)
triggerall = NumProjID(1600) < 1
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Teleport
;e|[g
[State -1, teleport]
type = ChangeState
value = 1700
triggerall = command = "236a"
triggerall = statetype = S ; || statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Teleport
;e|[g
[State -1, teleport]
type = ChangeState
value = 1710
triggerall = command = "236b"
triggerall = statetype = S ; || statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Teleport
;e|[g
[State -1, teleport]
type = ChangeState
value = 1720
triggerall = command = "236c"
triggerall = statetype = S ; || statetype = A
trigger1 = ctrl = 1

;===========================================================================
;---------------------------------------------------------------------------
; Op
[State -1, Swich Jump BF]
type = ChangeState
value = 60
Triggerall = backEdgeDist < 5
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = stateno != 60
trigger1 = command = "holdfwd"

;---------------------------------------------------------------------------
; Op
[State -1, Swich Jump FB]
type = ChangeState
value = 61
Triggerall = FrontEdgeDist < 5
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = stateno != 61
trigger1 = command = "holdback"

;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Psycic Throw
;
[State -1, Throw]
type = ChangeState
value = 800
triggerall = (command = "y") || (command = "z")
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 18
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 21
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;Psycic Shoot
;
[State -1, AirThrow]
type = ChangeState
value = 850
triggerall = (command = "y") || (command = "z")
triggerall = statetype = A
triggerall = p2statetype = A
triggerall = ctrl
trigger1 = command != "holdup"
trigger1 = p2bodydist X < 30
trigger1 = p2movetype != H
trigger1 = (command = "holdfwd") || (command = "holdback")


;===========================================================================
;---------------------------------------------------------------------------
;Escape
;U
[State -1, Escape]
type = ChangeState
value = 90
triggerall = command = "xa"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Sway Attack
;U
[State -1, Sway Attack]
type = ChangeState
value = 300
triggerall = command != "holddown"
triggerall = statetype = S
triggerall = (stateno = 90) && time < 23
trigger1   = command = "x"
trigger2   = command = "y"
trigger3   = command = "z"
trigger4   = command = "a"
trigger5   = command = "b"
trigger6   = command = "c"

;---------------------------------------------------------------------------
;Standing Strong Attack
;΂U
[State -1, Standing Strong Attack]
type = ChangeState
value = 350
triggerall = command = "zc"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Attack
;Wv΂U
[State -1, Standing Strong Attack]
type = ChangeState
value = 360
triggerall = command = "zc"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 630 || stateno = 640 || stateno = 650 
trigger2 = movecontact

;---------------------------------------------------------------------------
;Fhenix Bomb
;tFjbNX {
[State -1, Fhenix Bomb]
type = ChangeState
value = 700
triggerall = command = "down_c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 630 || stateno = 640 || stateno = 650 
trigger2 = movecontact

;---------------------------------------------------------------------------
; O咸Ii㒆ij
[State -1, Gaimon_Chu]
type = ChangeState
value = 310
triggerall = command != "holddown"
triggerall = statetype = S
triggerall = ctrl
trigger1   = (command = "back_xy") || (command = "back_yz") || (command = "back_xz")
trigger1   = (P2StateType = S) || (P2StateType = A)

;---------------------------------------------------------------------------
; O咸Iiij
[State -1, Gaimon_Chu]
type = ChangeState
value = 312
triggerall = command != "holddown"
triggerall = statetype = S
triggerall = ctrl
trigger1   = (command = "back_xy") || (command = "back_yz") || (command = "back_xz")
trigger1   = (P2StateType = C)

;---------------------------------------------------------------------------
; CeϛR
; ij
[State -1, RyusoSiki]
type = ChangeState
value = 330
triggerall = command != "holddown"
triggerall = statetype = S
triggerall = ctrl
trigger1   = (command = "fwd_ab") || (command = "fwd_ac") || (command = "fwd_bc")

;---------------------------------------------------------------------------
; R
;   I
[State -1, Kousyutai]
type = ChangeState
value = 340
triggerall   = (command = "back_ab") || (command = "back_bc") || (command = "back_ac")
triggerall = command != "holddown"
triggerall = p2bodydist X < 38
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; _goՏ
;   
[State -1, Bong Ken]
type = ChangeState
value = 370
triggerall = (command = "xy") || (command = "yz") || (command = "xz")
triggerall = command != "holddown"
triggerall = p2bodydist X < 48
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 220) && time > 5
trigger11 = (stateno = 221) && time > 6
trigger12 = (stateno = 250) && time > 5 && time < 10
trigger13 = (stateno = 251) && time > 12
trigger14 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440) || (stateno = 420) || (stateno = 450)
trigger14 = movecontact

;---------------------------------------------------------------------------
; p[
[State -1, Charge]
type = ChangeState
value = 900
triggerall = command != "holddown"
triggerall = p2bodydist X > 48
triggerall = stateno  = 0
trigger1   = (command = "ab") || (command = "ac") || (command = "bc") || (command = "xy") || (command = "xz") || (command = "yz")

;---------------------------------------------------------------------------
;Stand Light Punch
;p`i߁j
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;---------------------------------------------------------------------------
;Stand Light Punch
;p`ij
[State -1, Stand Light Punch]
type = ChangeState
value = 201
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6
trigger3 = stateno = 201
trigger3 = time > 6

;---------------------------------------------------------------------------
;Stand Middle Punch
;p`i߁j
[State -1, Stand Middle Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 400) || (stateno = 430)
trigger6 = movecontact

;---------------------------------------------------------------------------
;Stand Middle Punch
;p`ij
[State -1, Stand Middle Punch]
type = ChangeState
value = 211
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 400) || (stateno = 430)
trigger6 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`i߁j
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 6
trigger10 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440)
trigger10 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`ij
[State -1, Stand Strong Punch]
type = ChangeState
value = 221
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 6
trigger10 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440)
trigger10 = movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbNi߁j
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
;Stand Light Kick
;LbNij
[State -1, Stand Light Kick]
type = ChangeState
value = 231
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
;Standing Middle Kick
;LbNi߁j
[State -1, Standing Middle Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 400) || (stateno = 430)
trigger6 = movecontact

;---------------------------------------------------------------------------
;Standing Middle Kick
;LbNij
[State -1, Standing Middle Kick]
type = ChangeState
value = 241
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 400) || (stateno = 430)
trigger6 = movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbNi߁j
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440)
trigger10 = movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbNij
[State -1, Standing Strong Kick]
type = ChangeState
value = 251
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 32
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
trigger4 = (stateno = 201) && time > 5
trigger5 = (stateno = 231) && time > 6
trigger6 = (stateno = 210) && time > 5
trigger7 = (stateno = 240) && time > 6
trigger8 = (stateno = 211) && time > 5
trigger9 = (stateno = 241) && time > 12
trigger10 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440)
trigger10 = movecontact

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Middle Punch
;Ⴊݒp`
[State -1, Crouching Middle Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݏLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Middle Kick
;ႪݒLbN
[State -1, Crouching Middle Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430) || (stateno = 410) || (stateno = 440)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || stateno = 610 || stateno = 640
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || stateno = 610 || stateno = 640
trigger2 = movecontact


